@@ -11,7 +11,6 @@ __PACKAGE__->mk_accessors qw/
     name
     type
     default
-    validator
     readable writable
     length
     mandatory
@@ -25,6 +24,11 @@ __PACKAGE__->mk_accessors qw/
 
     label hints render_as
     valid_values
+    indexed
+    autocompleted
+    _validator
+    _checked_for_validate_sub
+    record_class
     /;
 
 =head1 NAME
@@ -49,7 +53,23 @@ sub is_numeric {
         return 1;
     }
     return 0;
+}
 
+sub validator {
+    my $self = shift;
+
+    if ( @_ ) {
+        $self->_validator( shift );
+    }
+    elsif ( not $self->_checked_for_validate_sub and not $self->_validator ) {
+        my $name = ( $self->aliased_as ? $self->aliased_as : $self->name );
+        my $can  = $self->record_class->can( "validate_" . $name );
+        
+        $self->_validator( $can ) if $can;
+        $self->_checked_for_validate_sub( 1 );
+    }
+
+    return $self->_validator;
 }
 
 # Aliases for compatibility with searchbuilder code
