@@ -9,7 +9,7 @@ Jifty::DBI::Schema - Use a simple syntax to describe a Jifty table.
 
 =head1 SYNOPSIS
 
-    package Wifty::Model::Page;
+    package MyApp::Model::Page;
     use Jifty::DBI::Schema;
     use Jifty::DBI::Record schema {
     # ... your columns here ...
@@ -43,7 +43,7 @@ associations between classes.
 use Carp qw/croak carp/;
 use Exporter::Lite;
 our @EXPORT
-    = qw(column type default literal validator immutable unreadable length distinct mandatory not_null sort_order valid_values label hints render_as render since input_filters output_filters filters virtual is as by are on schema);
+    = qw(column type default literal validator autocompleted immutable unreadable length distinct mandatory not_null sort_order valid_values label hints render_as render since input_filters output_filters filters virtual is as by are on schema indexed valid order);
 
 our $SCHEMA;
 our $SORT_ORDERS = {};
@@ -301,7 +301,7 @@ sub mandatory {
 
 =head2 not_null
 
-Same as L</mandatory>.  This is depricated.  Currect usage would be
+Same as L</mandatory>.  This is deprecated.  Currect usage would be
 C<is not_null>.
 
 =cut
@@ -311,6 +311,17 @@ sub not_null {
     _item( mandatory => 1, @_ );
 }
 
+=head2 autocompleted
+
+Mark as an autocompleted column.  May be used for generating user
+interfaces.  Correct usage is C<is autocompleted>.
+
+=cut
+
+sub autocompleted {
+    _item( autocompleted => 1, @_ );
+}
+
 =head2 distinct
 
 Declares that a column should only have distinct values.  This
@@ -349,6 +360,14 @@ sub sort_order {
     _item ( sort_order => (shift @_ || 0));
 }
 
+=head2 order
+
+Alias for C<sort_order>.
+
+=cut
+
+sub order { sort_order(@_) }
+
 
 =head2 input_filters
 
@@ -513,6 +532,17 @@ sub render {
     _list( render_as => @_ );
 }
 
+=head2 indexed
+
+An index will be built on this column
+Correct usage is C<is indexed>
+
+=cut
+
+sub indexed {
+    _list( indexed => 1, @_ );
+}
+
 =head2 by
 
 Helper method to improve readability.
@@ -607,6 +637,7 @@ under the same terms as Perl itself.
 package Jifty::DBI::Schema::Trait;
 
 use overload "!" => \&negation;
+use Carp qw/croak/;
 
 sub new {
     my $class = shift;
